@@ -15,6 +15,19 @@ class TextClassificationLoader(Loader):
         please refer to `test_loaders.py`
     """
 
+    def __init__(self, source: Source, file_type: Enum, data :str = None):
+
+        if source == None:
+            source = Source.local_filesystem
+        if file_type == None:
+            file_type = FileType.tsv
+
+
+        self._source = source
+        self._file_type = file_type
+        self._data = data
+
+
     def load(self) -> Iterable[Dict]:
         """
         :param path_system_output: the path of system output file with following format:
