@@ -67,5 +67,11 @@ class NERProcessor(Processor):
     })
 
     def __init__(self, metadata: dict, system_output_data: Iterable[dict]) -> None:
+        if metadata == None:
+            metadata = {}
+        if "task_name" not in metadata.keys():
+            metadata["task_name"] = TaskType.named_entity_recognition.value
+        if "metric_names" not in metadata.keys():
+            metadata["metric_names"] = ["f1_score_seqeval"]
         super().__init__(metadata, system_output_data)
         self._builder = NERExplainaboardBuilder(self._system_output_info, system_output_data)
\ No newline at end of file
