@@ -41,5 +41,11 @@ class TextClassificationProcessor(Processor):
 
 
     def __init__(self, metadata: dict, system_output_data: Iterable[dict]) -> None:
+        if metadata == None:
+            metadata = {}
+        if "task_name" not in metadata.keys():
+            metadata["task_name"] = TaskType.text_classification.value
+        if "metric_names" not in metadata.keys():
+            metadata["metric_names"] = ["Accuracy"]
         super().__init__(metadata, system_output_data)
         self._builder = TCExplainaboardBuilder(self._system_output_info, system_output_data)
\ No newline at end of file
