@@ -14,7 +14,7 @@ class TestNER(unittest.TestCase):
         loader = get_loader(TaskType.named_entity_recognition, Source.local_filesystem, FileType.conll, path_data)
         data = loader.load()
 
-        metadata = {"task_name": TaskType.named_entity_recognition,
+        metadata = {"task_name": TaskType.named_entity_recognition.value,
                     "dataset_name":"conll2003",
                     "metric_names": ["f1_score_seqeval"]}
 
