@@ -5,20 +5,20 @@ from explainaboard.constants import TaskType
 from explainaboard import FileType, Source, TaskType, get_loader, get_processor
 
 artifacts_path = os.path.dirname(pathlib.Path(__file__)) + "/artifacts/"
-class TestNER(unittest.TestCase):
+class TestSumm(unittest.TestCase):
 
     def test_generate_system_analysis(self):
         """TODO: should add harder tests"""
 
         path_data = artifacts_path+ "test-summ.tsv"
-        loader = get_loader(TaskType.text_summarization, Source.local_filesystem, FileType.tsv, path_data)
+        loader = get_loader(TaskType.summarization, Source.local_filesystem, FileType.tsv, path_data)
         data = loader.load()
 
-        metadata = {"task_name": TaskType.text_summarization,
+        metadata = {"task_name": TaskType.summarization.value,
                     "dataset_name":"cnndm",
                     "metric_names": ["bleu"]}
 
-        processor = get_processor(TaskType.text_summarization, metadata, data)
+        processor = get_processor(TaskType.summarization, metadata, data)
         #self.assertEqual(len(processor._features), 4)
 
         analysis = processor.process()
