@@ -19,7 +19,8 @@ class TestTextClassification(unittest.TestCase):
 
     def test_generate_system_analysis(self):
         """TODO: should add harder tests"""
-        metadata = {"task_name": TaskType.text_classification,
+
+        metadata = {"task_name": TaskType.text_classification.value,
             "metric_names": ["Accuracy", "F1score"]}
 
         processor = get_processor(TaskType.text_classification, metadata, self._system_output_data)
@@ -31,7 +32,8 @@ class TestTextClassification(unittest.TestCase):
         self.assertGreater(len(analysis.results.overall), 0)
     
     def test_e2e(self):
-        metadata = {"task_name": TaskType.text_classification,
+
+        metadata = {"task_name": TaskType.text_classification.value,
             "metric_names": ["Accuracy", "F1score"]}
         loader = get_loader(TaskType.text_classification, Source.in_memory, FileType.tsv,
                             load_file_as_str(f"{artifacts_path}sys_out1.tsv"))
@@ -40,6 +42,7 @@ class TestTextClassification(unittest.TestCase):
         self.assertEqual(len(processor._features), 6)
 
         analysis = processor.process()
+
         analysis.write_to_directory("./")
         self.assertListEqual(analysis.metric_names, metadata["metric_names"])
         self.assertIsNotNone(analysis.results.fine_grained)
